@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE games lskat program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games lskat program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "engine_two.h"
@@ -23,7 +10,7 @@
 // Qt includes
 #include <QTimer>
 
-// KDE includes
+// KF includes
 #include <KLocalizedString>
 
 // Local includes
@@ -203,7 +190,7 @@ void EngineTwo::gameLoopFinish()
         mGameStatus = Stopped;
         mDisplay->showMove(-1);
         int winner = evaluateGame();
-        emit signalGameOver(winner);
+        Q_EMIT signalGameOver(winner);
     }
     // Game continues
     else
@@ -359,7 +346,7 @@ void EngineTwo::stopGame()
 
         // Set game status to stopped
         mGameStatus    = Stopped;
-        emit signalGameOver(-2);
+        Q_EMIT signalGameOver(-2);
     }
 }
 
@@ -377,7 +364,7 @@ void EngineTwo::activatePlayer(int playerNumber)
     mDisplay->showMove(playerNumber);
     mCurrentPlayer = playerNumber;
 
-    emit signalNextPlayer(player);
+    Q_EMIT signalNextPlayer(player);
 }
 
 // Check whether the two cards played are legal, supposed the
